<?php


namespace Ardent\PicnicApi;


use Ardent\PicnicApi\Objects\ApiListTransformer;
use Ardent\PicnicApi\Objects\Category;
use Ardent\PicnicApi\Objects\Delivery;
use Ardent\PicnicApi\Objects\Order;

class PicnicClient
{
    private Client $client;

    public function __construct(string $username, string $password)
    {
        $this->client = new Client($username, $password);
    }

    public function getUser()
    {
        return $this->client->get('user');
    }

    public function getCart(): Order
    {
        return ApiListTransformer::getObject($this->client->get('cart'));
    }

    /**
     * Returns all past and current deliveries of the user.
     *
     * @param bool  $summary Return a summary (less data).
     * @param array $filters An array with the statusses of the deliveries. For example; ['COMPLETED'] will only get completed deliveries. Possible options include CURRENT, COMPLETED and CANCELLED.
     *
     * @return Delivery[]
     */
    public function getDeliveries(bool $summary = false, array $filters = []): array
    {
        $summary = $summary ? '/summary' : '';
        $data = $this->client->post('deliveries' . $summary, $filters);
        return ApiListTransformer::getObjects($data);
    }

    /**
     * @param string $term
     *
     * @return Category[]
     */
    public function search(string $term): array
    {
        return ApiListTransformer::getObjects($this->client->get(sprintf('search?search_term=%s', urlencode($term))));
    }
}